@@ -1,7 +1,7 @@
 package Perinci::Examples::Stream;
 
 our $DATE = '2016-01-22'; # DATE
-our $VERSION = '0.66'; # VERSION
+our $VERSION = '0.67'; # VERSION
 
 use 5.010;
 use strict;
@@ -99,6 +99,33 @@ sub word_err {
      }];
 }
 
+$SPEC{num_words} = {
+    v => 1.1,
+    summary => 'This function receives a stream of words and return the number of words',
+    description => <<'_',
+
+Input validation will check that each record from the stream is a word.
+
+_
+    args => {
+        words => {
+            schema => ['str*', match=>'\A\w+\z'],
+            stream => 1,
+            cmdline_src => 'stdin_or_files',
+        },
+    },
+};
+sub num_words {
+    my %args = @_;
+
+    my $words = $args{words};
+    my $num = 0;
+    while (defined($words->())) {
+        $num++;
+    }
+    [200, "OK", $num];
+}
+
 $SPEC{hash_stream} = {
     v => 1.1,
     summary => 'This function produces a stream of hashes',
@@ -289,7 +316,7 @@ Perinci::Examples::Stream - Examples for streaming input/output
 
 =head1 VERSION
 
-This document describes version 0.66 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2016-01-22.
+This document describes version 0.67 of Perinci::Examples::Stream (from Perl distribution Perinci-Examples), released on 2016-01-22.
 
 =head1 DESCRIPTION
 
@@ -353,6 +380,34 @@ that contains extra information.
 Return value:  (int)
 
 
+=head2 num_words(%args) -> [status, msg, result, meta]
+
+This function receives a stream of words and return the number of words.
+
+Input validation will check that each record from the stream is a word.
+
+This function is not exportable.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<words> => I<str>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 square_input(%args) -> [status, msg, result, meta]
 
 This function squares its stream input.
